@@ -33,6 +33,8 @@ pub const LATEST_VERSION_FILENAME: &str = "latest_version";
 pub const HOST_ID_FILENAME: &str = "host_id";
 static EXAMPLE_CONFIG: &str = include_str!("../config.toml");
 
+mod dotfiles;
+
 #[derive(Clone, Debug, Deserialize, Copy, ValueEnum, PartialEq)]
 pub enum SearchMode {
     #[serde(rename = "prefix")]
@@ -151,7 +153,11 @@ impl FromStr for Timezone {
     fn from_str(s: &str) -> Result<Self> {
         // local timezone
         if matches!(s.to_lowercase().as_str(), "l" | "local") {
-            let offset = UtcOffset::current_local_offset()?;
+            // There have been some timezone issues, related to errors fetching it on some
+            // platforms
+            // Rather than fail to start, fallback to UTC. The user should still be able to specify
+            // their timezone manually in the config file.
+            let offset = UtcOffset::current_local_offset().unwrap_or(UtcOffset::UTC);
             return Ok(Self(offset));
         }
 
@@ -270,6 +276,8 @@ pub struct Stats {
     pub common_prefix: Vec<String>, // sudo, etc. commands we want to strip off
     #[serde(default = "Stats::common_subcommands_default")]
     pub common_subcommands: Vec<String>, // kubectl, commands we should consider subcommands for
+    #[serde(default = "Stats::ignored_commands_default")]
+    pub ignored_commands: Vec<String>, // cd, ls, etc. commands we want to completely hide from stats
 }
 
 impl Stats {
@@ -278,10 +286,34 @@ impl Stats {
     }
 
     fn common_subcommands_default() -> Vec<String> {
-        vec!["cargo", "go", "git", "npm", "yarn", "pnpm", "kubectl"]
-            .into_iter()
-            .map(String::from)
-            .collect()
+        vec![
+            "apt",
+            "cargo",
+            "composer",
+            "dnf",
+            "docker",
+            "git",
+            "go",
+            "ip",
+            "kubectl",
+            "nix",
+            "nmcli",
+            "npm",
+            "pecl",
+            "pnpm",
+            "podman",
+            "port",
+            "systemctl",
+            "tmux",
+            "yarn",
+        ]
+        .into_iter()
+        .map(String::from)
+        .collect()
+    }
+
+    fn ignored_commands_default() -> Vec<String> {
+        vec![]
     }
 }
 
@@ -290,6 +322,7 @@ impl Default for Stats {
         Self {
             common_prefix: Self::common_prefix_default(),
             common_subcommands: Self::common_subcommands_default(),
+            ignored_commands: Self::ignored_commands_default(),
         }
     }
 }
@@ -299,6 +332,11 @@ pub struct Sync {
     pub records: bool,
 }
 
+#[derive(Clone, Debug, Deserialize, Default)]
+pub struct Keys {
+    pub scroll_exits: bool,
+}
+
 #[derive(Clone, Debug, Deserialize)]
 pub struct Settings {
     pub dialect: Dialect,
@@ -322,6 +360,7 @@ pub struct Settings {
     pub show_preview: bool,
     pub max_preview_height: u16,
     pub show_help: bool,
+    pub show_tabs: bool,
     pub exit_mode: ExitMode,
     pub keymap_mode: KeymapMode,
     pub keymap_mode_shell: KeymapMode,
@@ -353,6 +392,12 @@ pub struct Settings {
     #[serde(default)]
     pub sync: Sync,
 
+    #[serde(default)]
+    pub keys: Keys,
+
+    #[serde(default)]
+    pub dotfiles: dotfiles::Settings,
+
     // This is automatically loaded when settings is created. Do not set in
     // config! Keep secrets and settings apart.
     #[serde(skip)]
@@ -558,6 +603,7 @@ impl Settings {
             .set_default("show_preview", false)?
             .set_default("max_preview_height", 4)?
             .set_default("show_help", true)?
+            .set_default("show_tabs", true)?
             .set_default("invert", false)?
             .set_default("exit_mode", "return-original")?
             .set_default("word_jump_mode", "emacs")?
@@ -581,6 +627,7 @@ impl Settings {
             // New users will get the new default, that is more similar to what they are used to.
             .set_default("enter_accept", false)?
             .set_default("sync.records", false)?
+            .set_default("keys.scroll_exits", true)?
             .set_default("keymap_mode", "emacs")?
             .set_default("keymap_mode_shell", "auto")?
             .set_default("keymap_cursor", HashMap::<String, String>::new())?
