@@ -39,7 +39,7 @@ use ratatui::{
     prelude::*,
     style::{Color, Modifier, Style},
     text::{Line, Span, Text},
-    widgets::{Block, BorderType, Borders, Paragraph, Tabs},
+    widgets::{block::Title, Block, BorderType, Borders, Padding, Paragraph, Tabs},
     Frame, Terminal, TerminalOptions, Viewport,
 };
 
@@ -189,11 +189,15 @@ impl State {
         }
 
         let ctrl = input.modifiers.contains(KeyModifiers::CONTROL);
+        let esc_allow_exit = !(self.tab_index == 0 && self.keymap_mode == KeymapMode::VimInsert);
 
         // core input handling, common for all tabs
         match input.code {
             KeyCode::Char('c' | 'g') if ctrl => return InputAction::ReturnOriginal,
-            KeyCode::Esc if !(self.tab_index == 0 && self.keymap_mode == KeymapMode::VimInsert) => {
+            KeyCode::Esc if esc_allow_exit => {
+                return Self::handle_key_exit(settings);
+            }
+            KeyCode::Char('[') if ctrl && esc_allow_exit => {
                 return Self::handle_key_exit(settings);
             }
             KeyCode::Tab => {
@@ -225,7 +229,7 @@ impl State {
         is_down: bool,
     ) -> InputAction {
         if is_down {
-            if enable_exit && self.results_state.selected() == 0 {
+            if settings.keys.scroll_exits && enable_exit && self.results_state.selected() == 0 {
                 return Self::handle_key_exit(settings);
             }
             self.scroll_down(1);
@@ -243,6 +247,13 @@ impl State {
         self.handle_search_scroll_one_line(settings, enable_exit, !settings.invert)
     }
 
+    fn handle_search_accept(&mut self, settings: &Settings) -> InputAction {
+        if settings.enter_accept {
+            self.accept = true;
+        }
+        InputAction::Accept(self.results_state.selected())
+    }
+
     #[allow(clippy::too_many_lines)]
     #[allow(clippy::cognitive_complexity)]
     fn handle_search_input(&mut self, settings: &Settings, input: &KeyEvent) -> InputAction {
@@ -258,24 +269,62 @@ impl State {
         // First handle keymap specific keybindings.
         match self.keymap_mode {
             KeymapMode::VimNormal => match input.code {
+                KeyCode::Char('/') if !ctrl => {
+                    self.search.input.clear();
+                    self.set_keymap_cursor(settings, "vim_insert");
+                    self.keymap_mode = KeymapMode::VimInsert;
+                    return InputAction::Continue;
+                }
+                KeyCode::Char('?') if !ctrl => {
+                    self.search.input.clear();
+                    self.set_keymap_cursor(settings, "vim_insert");
+                    self.keymap_mode = KeymapMode::VimInsert;
+                    return InputAction::Continue;
+                }
                 KeyCode::Char('j') if !ctrl => {
                     return self.handle_search_down(settings, true);
                 }
                 KeyCode::Char('k') if !ctrl => {
                     return self.handle_search_up(settings, true);
                 }
+                KeyCode::Char('h') if !ctrl => {
+                    self.search.input.left();
+                    return InputAction::Continue;
+                }
+                KeyCode::Char('l') if !ctrl => {
+                    self.search.input.right();
+                    return InputAction::Continue;
+                }
+                KeyCode::Char('a') if !ctrl => {
+                    self.search.input.right();
+                    self.set_keymap_cursor(settings, "vim_insert");
+                    self.keymap_mode = KeymapMode::VimInsert;
+                    return InputAction::Continue;
+                }
+                KeyCode::Char('A') if !ctrl => {
+                    self.search.input.end();
+                    self.set_keymap_cursor(settings, "vim_insert");
+                    self.keymap_mode = KeymapMode::VimInsert;
+                    return InputAction::Continue;
+                }
                 KeyCode::Char('i') if !ctrl => {
                     self.set_keymap_cursor(settings, "vim_insert");
                     self.keymap_mode = KeymapMode::VimInsert;
                     return InputAction::Continue;
                 }
+                KeyCode::Char('I') if !ctrl => {
+                    self.search.input.start();
+                    self.set_keymap_cursor(settings, "vim_insert");
+                    self.keymap_mode = KeymapMode::VimInsert;
+                    return InputAction::Continue;
+                }
                 KeyCode::Char(_) if !ctrl => {
                     return InputAction::Continue;
                 }
                 _ => {}
             },
             KeymapMode::VimInsert => {
-                if input.code == KeyCode::Esc {
+                if input.code == KeyCode::Esc || (ctrl && input.code == KeyCode::Char('[')) {
                     self.set_keymap_cursor(settings, "vim_normal");
                     self.keymap_mode = KeymapMode::VimNormal;
                     return InputAction::Continue;
@@ -285,13 +334,8 @@ impl State {
         }
 
         match input.code {
-            KeyCode::Enter => {
-                if settings.enter_accept {
-                    self.accept = true;
-                }
-
-                return InputAction::Accept(self.results_state.selected());
-            }
+            KeyCode::Enter => return self.handle_search_accept(settings),
+            KeyCode::Char('m') if ctrl => return self.handle_search_accept(settings),
             KeyCode::Char('y') if ctrl => {
                 return InputAction::Copy(self.results_state.selected());
             }
@@ -478,6 +522,7 @@ impl State {
             1
         };
         let show_help = settings.show_help && (!compact || f.size().height > 1);
+        let show_tabs = settings.show_tabs;
         let chunks = Layout::default()
             .direction(Direction::Vertical)
             .margin(0)
@@ -488,13 +533,13 @@ impl State {
                         Constraint::Length(1 + border_size),               // input
                         Constraint::Min(1),                                // results list
                         Constraint::Length(preview_height),                // preview
-                        Constraint::Length(1),                             // tabs
+                        Constraint::Length(if show_tabs { 1 } else { 0 }), // tabs
                         Constraint::Length(if show_help { 1 } else { 0 }), // header (sic)
                     ]
                 } else {
                     [
                         Constraint::Length(if show_help { 1 } else { 0 }), // header
-                        Constraint::Length(1),                             // tabs
+                        Constraint::Length(if show_tabs { 1 } else { 0 }), // tabs
                         Constraint::Min(1),                                // results list
                         Constraint::Length(1 + border_size),               // input
                         Constraint::Length(preview_height),                // preview
@@ -558,12 +603,26 @@ impl State {
             }
 
             1 => {
-                super::inspector::draw(
-                    f,
-                    results_list_chunk,
-                    &results[self.results_state.selected()],
-                    &stats.expect("Drawing inspector, but no stats"),
-                );
+                if results.is_empty() {
+                    let message = Paragraph::new("Nothing to inspect")
+                        .block(
+                            Block::new()
+                                .title(
+                                    Title::from(" Info ".to_string()).alignment(Alignment::Center),
+                                )
+                                .borders(Borders::ALL)
+                                .padding(Padding::vertical(2)),
+                        )
+                        .alignment(Alignment::Center);
+                    f.render_widget(message, results_list_chunk);
+                } else {
+                    super::inspector::draw(
+                        f,
+                        results_list_chunk,
+                        &results[self.results_state.selected()],
+                        &stats.expect("Drawing inspector, but no stats"),
+                    );
+                }
 
                 // HACK: I'm following up with abstracting this into the UI container, with a
                 // sub-widget for search + for inspector
@@ -581,6 +640,11 @@ impl State {
         let input = self.build_input(style);
         f.render_widget(input, input_chunk);
 
+        let preview_width = if compact {
+            preview_width
+        } else {
+            preview_width - 2
+        };
         let preview =
             self.build_preview(results, compact, preview_width, preview_chunk.width.into());
         f.render_widget(preview, preview_chunk);
@@ -966,9 +1030,11 @@ pub async fn history(
 
         stats = if app.tab_index == 0 {
             None
-        } else {
+        } else if !results.is_empty() {
             let selected = results[app.results_state.selected()].clone();
             Some(db.stats(&selected).await?)
+        } else {
+            None
         };
     };
 
@@ -1008,10 +1074,18 @@ pub async fn history(
     }
 }
 
-#[cfg(feature = "clipboard")]
+// cli-clipboard only works on Windows, Mac, and Linux.
+
+#[cfg(all(
+    feature = "clipboard",
+    any(target_os = "windows", target_os = "macos", target_os = "linux")
+))]
 fn set_clipboard(s: String) {
     cli_clipboard::set_contents(s).unwrap();
 }
 
-#[cfg(not(feature = "clipboard"))]
+#[cfg(not(all(
+    feature = "clipboard",
+    any(target_os = "windows", target_os = "macos", target_os = "linux")
+)))]
 fn set_clipboard(_s: String) {}
