@@ -1,9 +1,19 @@
+use std::path::PathBuf;
+
 use crate::{SHA, VERSION};
 use atuin_client::{api_client, database::Database, settings::Settings};
 use colored::Colorize;
 use eyre::Result;
 
 pub async fn run(settings: &Settings, db: &impl Database) -> Result<()> {
+    let session_path = settings.session_path.as_str();
+
+    if !PathBuf::from(session_path).exists() {
+        println!("You are not logged in to a sync server - cannot show sync status");
+
+        return Ok(());
+    }
+
     let client = api_client::Client::new(
         &settings.sync_address,
         &settings.session_token,
@@ -25,14 +35,15 @@ pub async fn run(settings: &Settings, db: &impl Database) -> Result<()> {
         println!("Last sync: {last_sync}");
     }
 
-    println!("History count: {local_count}");
-    println!("Deleted history count: {deleted_count}\n");
+    if !settings.sync.records {
+        println!("History count: {local_count}");
+        println!("Deleted history count: {deleted_count}\n");
+    }
 
     if settings.auto_sync {
         println!("{}", "[Remote]".green());
         println!("Address: {}", settings.sync_address);
         println!("Username: {}", status.username);
-        println!("History count: {}", status.count);
     }
 
     Ok(())
